lexicons\_builder.wordnet\_explorer package
===========================================

.. automodule:: lexicons_builder.wordnet_explorer
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

lexicons\_builder.wordnet\_explorer.explorer module
---------------------------------------------------

.. automodule:: lexicons_builder.wordnet_explorer.explorer
   :members:
   :undoc-members:
   :show-inheritance:
